<img width="120px" alt="cowplot logo" align="right" src="man/figures/logo.png">

# cowplot – Streamlined plot theme and plot annotations for ggplot2

<!-- badges: start -->
[![R build status](https://github.com/wilkelab/cowplot/workflows/R-CMD-check/badge.svg)](https://github.com/wilkelab/cowplot/actions)
[![CRAN\_Status\_Badge](https://www.r-pkg.org/badges/version/cowplot)](https://CRAN.R-project.org/package=cowplot)
[![CRAN\_Downloads\_Badge](https://cranlogs.r-pkg.org/badges/cowplot)](https://cranlogs.r-pkg.org/downloads/total/last-month/cowplot)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2533860.svg)](https://doi.org/10.5281/zenodo.2533860)

<!-- badges: end -->

The cowplot package provides various features that help with creating publication-quality figures, such as a set of themes, functions to align plots and arrange them into complex compound figures, and functions that make it easy to annotate plots and or mix plots with images. The package was originally written for internal use in the Wilke lab, hence the name (Claus O. Wilke's plot package). It has also been used extensively in the book  [Fundamentals of Data Visualization.](https://clauswilke.com/dataviz/)

# Installation

The cowplot package is available on [CRAN](https://cran.r-project.org/package=cowplot) and can be installed via

    install.packages("cowplot")
    
To install the latest development version of the package using the devtools package, enter the following in your R console:

    remotes::install_github("wilkelab/cowplot")

# Usage

To get a quick introduction to the main features of this package, read the [introductory vignette.](https://wilkelab.org/cowplot/articles/introduction.html) For a more in-depth discussion, read [all vignettes](https://wilkelab.org/cowplot/articles/index.html) and/or the [reference documentation.](https://wilkelab.org/cowplot/reference/index.html)

